<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://codingfix.com
 * @since      1.0.0
 *
 * @package    Cfx_Language_Switcher_For_Transposh
 * @subpackage Cfx_Language_Switcher_For_Transposh/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Cfx_Language_Switcher_For_Transposh
 * @subpackage Cfx_Language_Switcher_For_Transposh/admin
 * @author     Marco Gasi <codingfix@codingfix.com>
 */
class Cfx_Language_Switcher_For_Transposh_Admin
{

  /**
   * The ID of this plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      string    $plugin_name    The ID of this plugin.
   */
  private $plugin_name;

  /**
   * The version of this plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      string    $version    The current version of this plugin.
   */
  private $version;

  /**
   * The options for this plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      string    $version    The options for this plugin.
   */
  private $options;

  /**
   * Initialize the class and set its properties.
   *
   * @since    1.0.0
   * @param      string    $plugin_name       The name of this plugin.
   * @param      string    $version    The version of this plugin.
   */
  public function __construct($plugin_name, $version)
  {

    $this->plugin_name = $plugin_name;
    $this->version = $version;
    $this->options = get_option('cfxlsft_options');
  }

  public function cfxlsft_admin_init()
  {
  }

  /**
   * Register the stylesheets for the admin area.
   *
   * @since    1.0.0
   */
  public function enqueue_styles()
  {
    wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/cfx-language-switcher-for-transposh-admin.css', array(), $this->version, 'all');
  }

  /**
   * Register the JavaScript for the admin area.
   *
   * @since    1.0.0
   */
  public function enqueue_scripts()
  {
    wp_enqueue_script('cfx_language_switcher_for_transposh_admin_js', plugin_dir_url(__FILE__) . 'js/cfx-language-switcher-for-transposh-admin.js', array('jquery'), $this->version, false);
    wp_enqueue_code_editor(array('type' => 'text/css'));
    wp_localize_script(
      'cfx_language_switcher_for_transposh_admin_js',
      'ajax_object',
      array('ajax_url' => admin_url('admin-ajax.php'), 'we_value' => 1234)
    );
  }

  /**
   * Register the Settings page.
   *
   * @since    1.0.0
   */
  public function cfxlsft_admin_menu()
  {
    add_options_page(__('Language Switcher for Transposh Configuration', $this->plugin_name), __('Language Switcher for Transposh Configuration', $this->plugin_name), 'manage_options', 'language-switcher-settings', array($this, 'display_plugin_admin_page'));
  }

  /**
   * Load correct style
   *
   * @since     1.0.0
   */
  public function load_style()
  {
    $style = filter_input(INPUT_POST, 'style', FILTER_SANITIZE_STRING);
    $folder = filter_input(INPUT_POST, 'folder', FILTER_SANITIZE_STRING);
    $basic = filter_input(INPUT_POST, 'basic', FILTER_SANITIZE_NUMBER_INT);

    // $style = $_POST['style'];
    // $folder = $_POST['folder'];
    // $basic = $_POST['basic'];

    $css = (int)$basic === 1 ? file_get_contents(LSFT_PLUGIN_URL . "/assets/styles/basic-$folder.css") : file_get_contents(LSFT_PLUGIN_URL . "/assets/styles/$folder/$style");

    echo $css;
    wp_die();
  }

  public function process_cfxlsft_options()
  {
    $options = get_option('cfxlsft_options');
    if (!current_user_can('manage_options'))
      wp_die('Not allowed');
    check_admin_referer('cfxlsft');

    if (isset($_POST['flag_type'])) {
      $options['flag_type'] = sanitize_text_field($_POST['flag_type']);
    }

    if (isset($_POST['menu_classes'])) {
      $options['menu_classes'] = sanitize_text_field($_POST['menu_classes']);
    }

    if (isset($_POST['switcher_type'])) {
      $options['switcher_type'] = sanitize_text_field($_POST['switcher_type']);
    }

    $options['select_as_list'] = isset($_POST['select_as_list']) ? 'yes' : 'no';

    if (isset($_POST['select_style'])) {
      $options['select_style'] = sanitize_text_field($_POST['select_style']);
    }

    if (isset($_POST['list_style'])) {
      $options['list_style'] = sanitize_text_field($_POST['list_style']);
    }

    if (isset($_POST['flag_style'])) {
      $options['flag_style'] = sanitize_text_field($_POST['flag_style']);
    }

    if (isset($_POST['menu_locations'])) {
      $options['menu_locations'] = sanitize_text_field(implode(',', $_POST['menu_locations']));
    }

    if (isset($_POST['custom_style'])) {
      $fn = filter_input(INPUT_POST, 'filename', FILTER_SANITIZE_STRING);
      if (!empty($fn)) {
        if ($_POST['switcher_type'] == 'flags') {
          $fn_parts = explode('.', $fn);
          $filename = $fn_parts[0];
          $content = filter_input(INPUT_POST, 'custom_style', FILTER_SANITIZE_STRING, FILTER_FLAG_NO_ENCODE_QUOTES);
          $handler = fopen(LSFT_PLUGIN_PATH . "assets/styles/flags/$filename.css", 'w+');
          fwrite($handler, $content);
          fclose($handler);
          $options['flag_style'] = "$filename.css";
        } else {
          if (isset($_POST['select_as_list'])) {
            $fn_parts = explode('.', $fn);
            $filename = $fn_parts[0];
            $content = filter_input(INPUT_POST, 'custom_style', FILTER_SANITIZE_STRING, FILTER_FLAG_NO_ENCODE_QUOTES);
            $handler = fopen(LSFT_PLUGIN_PATH . "assets/styles/list/$filename.css", 'w+');
            fwrite($handler, $content);
            fclose($handler);
            $options['list_style'] = "$filename.css";
          } else {
            $fn_parts = explode('.', $fn);
            $filename = $fn_parts[0];
            $content = filter_input(INPUT_POST, 'custom_style', FILTER_SANITIZE_STRING, FILTER_FLAG_NO_ENCODE_QUOTES);
            $handler = fopen(LSFT_PLUGIN_PATH . "assets/styles/select/$filename.css", 'w+');
            fwrite($handler, $content);
            fclose($handler);
            $options['select_style'] = "$filename.css";
          }
        }
      } else {
        if ($_POST['switcher_type'] == 'flags') {
          $filename = sanitize_text_field($_POST['flag_style']);
          $content = filter_input(INPUT_POST, 'custom_style', FILTER_SANITIZE_STRING, FILTER_FLAG_NO_ENCODE_QUOTES);
          $handler = fopen(LSFT_PLUGIN_PATH . "assets/styles/flags/$filename", 'w+');
          fwrite($handler, $content);
          fclose($handler);
        } else {
          if (isset($_POST['select_as_list'])) {
            $filename = sanitize_text_field($_POST['list_style']);
            $content = filter_input(INPUT_POST, 'custom_style', FILTER_SANITIZE_STRING, FILTER_FLAG_NO_ENCODE_QUOTES);
            $handler = fopen(LSFT_PLUGIN_PATH . "assets/styles/list/$filename", 'w+');
            fwrite($handler, $content);
            fclose($handler);
          } else {
            $filename = sanitize_text_field($_POST['select_style']);
            $content = filter_input(INPUT_POST, 'custom_style', FILTER_SANITIZE_STRING, FILTER_FLAG_NO_ENCODE_QUOTES);
            $handler = fopen(LSFT_PLUGIN_PATH . "assets/styles/select/$filename", 'w+');
            fwrite($handler, $content);
            fclose($handler);
          }
        }
      }
    }

    if (isset($_POST['custom_list_items'])) {
      $options['custom_list_items'] = sanitize_text_field($_POST['custom_list_items']);
    }

    // exit;
    update_option('cfxlsft_options', $options);
    wp_redirect(add_query_arg(array('page' => 'language-switcher-settings', 'message' => '1'), admin_url('options-general.php')));
    exit;
  }

	/**
	 * Add a links near Deactivate link in the plugin list 
	 */
	public function add_action_links( $links ) {
		/*
		*  Documentation : https://codex.wordpress.org/Plugin_API/Filter_Reference/plugin_action_links_(plugin_file_name)
		*/
	   $settings_link = array(
		'<a href="' . admin_url( 'options-general.php?page=language-switcher-settings'  ) . '">' . __('Settings', $this->plugin_name) . '</a>',
	   );
	   return array_merge(  $settings_link, $links );
	
	}

  /**
   * Callback function for the admin settings page.
   *
   * @since    1.0.0
   */
  public function display_plugin_admin_page()
  {
    require_once plugin_dir_path(dirname(__FILE__)) . 'admin/partials/cfx-language-switcher-for-transposh-admin-display.php';
  }
}
